Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(298)

Unified Diff: components/user_prefs/tracked/pref_hash_calculator.h

Issue 2634403002: Use GetDeterministicMachineSpecificId instead of RLZ for device_id (Closed)
Patch Set: Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/user_prefs/tracked/pref_hash_calculator.h
diff --git a/components/user_prefs/tracked/pref_hash_calculator.h b/components/user_prefs/tracked/pref_hash_calculator.h
index 1f9b74f0ad75ab5b61f6ac6a3a7b07a1afbf83d4..9d02e2ce32f2b8f1763d6bbad7c24eea12db9b15 100644
--- a/components/user_prefs/tracked/pref_hash_calculator.h
+++ b/components/user_prefs/tracked/pref_hash_calculator.h
@@ -23,10 +23,13 @@ class PrefHashCalculator {
VALID_SECURE_LEGACY,
};
- // Constructs a PrefHashCalculator using |seed| and |device_id|. The same
- // parameters must be used in order to successfully validate generated hashes.
- // |device_id| may be empty.
- PrefHashCalculator(const std::string& seed, const std::string& device_id);
+ // Constructs a PrefHashCalculator using |seed|, |device_id| and
+ // |legacy_device_id|. The same parameters must be used in order to
gab 2017/01/17 21:03:47 nit: - extra space before "same"
proberge 2017/01/18 16:10:58 Done.
+ // successfully validate generated hashes. |_device_id| or |legacy_device_id|
+ // may be empty.
+ PrefHashCalculator(const std::string& seed,
+ const std::string& device_id,
+ const std::string& legacy_device_id);
~PrefHashCalculator();

Powered by Google App Engine
This is Rietveld 408576698